@@ -2,12 +2,12 @@ context("Checking as_count")
 
 test_that("as_count converts citations to counts",{
     
-    w <- structure(list(c("V. Raptor, 1986", "Foo, 2012"), "Rinker, 2014", 
+    w <- unlist(structure(list(c("V. Raptor, 1986", "Foo, 2012"), "Rinker, 2014", 
         "The R Core Team (2014)", "Bunn (2005)", "Baer, 2005", "Wickham's (in press)", 
         "Rinker's (n.d.)", c("Foo, 2012", "Bar, 2014"), "Uwe Ligges (2007)", 
         c("Bar, 2014", "Bar (2014, 2012)")), class = c("extracted", 
         "list")
-    )
+    ))
     
     exp <- structure(list(Author = c("Bar", "Bar", "Bunn", "Rinker", "The R Core Team", 
         "Uwe Ligges", "Wickham"), Year = c("2012", "2014", "2005", "n.d.", 
