@@ -8,7 +8,7 @@ test_that("rm_city_state_zip is removing city_state_zip strings",{
 
     x2 <- "I went to for food! It's in West , near !hello world"
 	
-    expect_true(identical(rm_city_state_zip(x), x2))
+    expect_equivalent(rm_city_state_zip(x), x2)
 	
 })
 
@@ -22,8 +22,7 @@ test_that("rm_city_state_zip is extracting city_state_zip strings",{
     x3 <- list(c("Washington Heights, NY 54321", "ven,PA 12345", "Bolly Bolly Bolly, CA12345-1234"
         ))
 
-    expect_true(identical(rm_city_state_zip(x, extract=TRUE), x3))
+    expect_equivalent(rm_city_state_zip(x, extract=TRUE), x3)
 })
 
 
-
