@@ -1,5 +1,6 @@
 context("Checking rm_non_ascii")
 
+skip_if(Sys.info()['sysname'] == 'Darwin' && as.numeric_version(Sys.info()[["release"]]) >= "23.0.0", message = NULL)
 test_that("rm_non_ascii is removing/replacing 'all abbreviation' strings",{
 
     x <- c("Hello World", "Ekstr\xf8m", "J\xf6reskog", "bi\xdfchen Z\xfcrcher")
@@ -7,8 +8,7 @@ test_that("rm_non_ascii is removing/replacing 'all abbreviation' strings",{
     x
     
     x1 <- c("Hello World", "Ekstrm", "Jreskog", "bichen Zrcher")
-    x2 <- c("Hello World", "Ekstr<<FLAG>>m", "J<<FLAG>>reskog", "bi<<FLAG>>chen Z<<FLAG>>rcher"
-        )
+    x2 <- c("Hello World", "Ekstr<<FLAG>>m", "J<<FLAG>>reskog", "bi<<FLAG>>chen Z<<FLAG>>rcher")
 
     
     expect_equivalent(rm_non_ascii(x), x1)
@@ -16,7 +16,6 @@ test_that("rm_non_ascii is removing/replacing 'all abbreviation' strings",{
 	
 })
 
-
 test_that("rm_non_ascii is extracting 'all non-ascii' strings",{
 	
     x <- c("Hello World", "Ekstr\xf8m", "J\xf6reskog", "bi\xdfchen Z\xfcrcher")
@@ -30,3 +29,4 @@ test_that("rm_non_ascii is extracting 'all non-ascii' strings",{
 })
 
 
+
